@@ -14,10 +14,11 @@ import time
 
 import numpy as np
 from joblib import Parallel, delayed
-from sklearn.utils.multiclass import class_distribution
 from sklearn.utils import check_random_state
+
 from sktime.classification.base import BaseClassifier
 from sktime.classification.dictionary_based import IndividualBOSS
+from sktime.utils.validation.panel import check_X_y
 
 
 class ContractableBOSS(BaseClassifier):
@@ -54,34 +55,39 @@ class ContractableBOSS(BaseClassifier):
         classifiers even if more than `max_ensemble_size` are within threshold.
     max_win_len_prop : int or float, default = 1
         Maximum window length as a proportion of the series length.
-    time_limit_in_minutes : int, default = 0
-        Time contract to limit build time in minutes. Default of 0 means no limit.
     min_window : int, default = 10
         Minimum window size.
+    time_limit_in_minutes : int, default = 0
+        Time contract to limit build time in minutes. Default of 0 means no limit.
+    contract_max_n_parameter_samples : int, default=np.inf
+        Max number of parameter combinations to consider when time_limit_in_minutes is
+        set.
+    save_train_predictions : bool, default=False
+        Save the ensemble member train predictions in fit for use in _get_train_probs
+        leave-one-out cross-validation.
     n_jobs : int, default = 1
-    The number of jobs to run in parallel for both `fit` and `predict`.
-    ``-1`` means using all processors.
+        The number of jobs to run in parallel for both `fit` and `predict`.
+        ``-1`` means using all processors.
     random_state : int or None, default=None
         Seed for random integer.
 
     Attributes
     ----------
-    n_classes : int
+    n_classes_ : int
         Number of classes. Extracted from the data.
-    n_instances : int
+    classes_ : list
+        The classes labels.
+    n_instances_ : int
         Number of instances. Extracted from the data.
-    n_estimators : int
+    n_estimators_ : int
         The final number of classifiers used. Will be <= `max_ensemble_size` if
         `max_ensemble_size` has been specified.
-    series_length : int
+    series_length_ : int
         Length of all series (assumed equal).
-    classifiers : list
+    estimators_ : list
        List of DecisionTree classifiers.
-    weights :
+    weights_ :
         Weight of each classifier in the ensemble.
-    class_dictionary: dict
-        Dictionary of classes. Extracted from the data.
-
 
     See Also
     --------
@@ -108,22 +114,19 @@ class ContractableBOSS(BaseClassifier):
     Examples
     --------
     >>> from sktime.classification.dictionary_based import ContractableBOSS
-    >>> from sktime.datasets import load_italy_power_demand
-    >>> X_train, y_train = load_italy_power_demand(split="train", return_X_y=True)
-    >>> X_test, y_test = load_italy_power_demand(split="test", return_X_y=True)
-    >>> clf = ContractableBOSS()
+    >>> from sktime.datasets import load_unit_test
+    >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
+    >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
+    >>> clf = ContractableBOSS(n_parameter_samples=25, max_ensemble_size=5)
     >>> clf.fit(X_train, y_train)
     ContractableBOSS(...)
     >>> y_pred = clf.predict(X_test)
     """
 
-    # Capability tags
     _tags = {
-        "capability:multivariate": False,
-        "capability:unequal_length": False,
-        "capability:missing_values": False,
         "capability:train_estimate": True,
         "capability:contractable": True,
+        "capability:multithreading": True,
     }
 
     def __init__(
@@ -133,35 +136,37 @@ class ContractableBOSS(BaseClassifier):
         max_win_len_prop=1,
         min_window=10,
         time_limit_in_minutes=0.0,
+        contract_max_n_parameter_samples=np.inf,
+        save_train_predictions=False,
         n_jobs=1,
         random_state=None,
     ):
         self.n_parameter_samples = n_parameter_samples
         self.max_ensemble_size = max_ensemble_size
         self.max_win_len_prop = max_win_len_prop
-        self.time_limit_in_minutes = time_limit_in_minutes
+        self.min_window = min_window
 
+        self.time_limit_in_minutes = time_limit_in_minutes
+        self.contract_max_n_parameter_samples = contract_max_n_parameter_samples
+        self.save_train_predictions = save_train_predictions
         self.n_jobs = n_jobs
         self.random_state = random_state
 
-        self.classifiers = []
-        self.weights = []
-        self.weight_sum = 0
-        self.n_classes = 0
-        self.classes_ = []
-        self.class_dictionary = {}
-        self.n_estimators = 0
-        self.series_length = 0
-        self.n_instances = 0
+        self.estimators_ = []
+        self.weights_ = []
+        self.n_estimators_ = 0
+        self.series_length_ = 0
+        self.n_instances_ = 0
+
+        self._weight_sum = 0
+        self._word_lengths = [16, 14, 12, 10, 8]
+        self._norm_options = [True, False]
+        self._alphabet_size = 4
 
-        self.word_lengths = [16, 14, 12, 10, 8]
-        self.norm_options = [True, False]
-        self.min_window = min_window
-        self.alphabet_size = 4
         super(ContractableBOSS, self).__init__()
 
     def _fit(self, X, y):
-        """Fit a c-boss ensemble on cases (X,y), where y is the target variable.
+        """Fit a cBOSS ensemble on cases (X,y), where y is the target variable.
 
         Build an ensemble of BOSS classifiers from the training set (X,
         y), through randomising over the para space to make a fixed size
@@ -169,28 +174,30 @@ class ContractableBOSS(BaseClassifier):
 
         Parameters
         ----------
-        X : nested pandas DataFrame of shape (n_instances, 1)
-            Nested dataframe with univariate time-series in cells.
-        y : array-like of shape (n_instances,)
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The training data.
+        y : array-like, shape = [n_instances]
             The class labels.
 
         Returns
         -------
-        self : object
+        self :
+            Reference to self.
+
+        Notes
+        -----
+        Changes state by creating a fitted model that updates attributes
+        ending in "_" and sets is_fitted flag to True.
         """
         time_limit = self.time_limit_in_minutes * 60
-        self.n_instances, _, self.series_length = X.shape
-        self.n_classes = np.unique(y).shape[0]
-        self.classes_ = class_distribution(np.asarray(y).reshape(-1, 1))[0][0]
-        for index, classVal in enumerate(self.classes_):
-            self.class_dictionary[classVal] = index
+        self.n_instances_, _, self.series_length_ = X.shape
 
-        self.classifiers = []
-        self.weights = []
+        self.estimators_ = []
+        self.weights_ = []
 
         # Window length parameter space dependent on series length
-        max_window_searches = self.series_length / 4
-        max_window = int(self.series_length * self.max_win_len_prop)
+        max_window_searches = self.series_length_ / 4
+        max_window = int(self.series_length_ * self.max_win_len_prop)
         win_inc = int((max_window - self.min_window) / max_window_searches)
         if win_inc < 1:
             win_inc = 1
@@ -198,9 +205,8 @@ class ContractableBOSS(BaseClassifier):
             raise ValueError(
                 f"Error in ContractableBOSS, min_window ="
                 f"{self.min_window} is bigger"
-                f" than max_window ={max_window},"
-                f" series length is {self.series_length}"
-                f" try set min_window to be smaller than series length in "
+                f" than max_window ={max_window}."
+                f" Try set min_window to be smaller than series length in "
                 f"the constructor, but the classifier may not work at "
                 f"all with very short series"
             )
@@ -208,63 +214,75 @@ class ContractableBOSS(BaseClassifier):
         num_classifiers = 0
         start_time = time.time()
         train_time = 0
-        subsample_size = int(self.n_instances * 0.7)
+        subsample_size = int(self.n_instances_ * 0.7)
         lowest_acc = 1
         lowest_acc_idx = 0
 
         rng = check_random_state(self.random_state)
 
         if time_limit > 0:
-            self.n_parameter_samples = 0
+            n_parameter_samples = 0
+            contract_max_n_parameter_samples = self.contract_max_n_parameter_samples
+        else:
+            n_parameter_samples = self.n_parameter_samples
+            contract_max_n_parameter_samples = np.inf
 
         while (
-            train_time < time_limit or num_classifiers < self.n_parameter_samples
+            (
+                train_time < time_limit
+                and num_classifiers < contract_max_n_parameter_samples
+            )
+            or num_classifiers < n_parameter_samples
         ) and len(possible_parameters) > 0:
             parameters = possible_parameters.pop(
                 rng.randint(0, len(possible_parameters))
             )
 
-            subsample = rng.choice(self.n_instances, size=subsample_size, replace=False)
+            subsample = rng.choice(
+                self.n_instances_, size=subsample_size, replace=False
+            )
             X_subsample = X[subsample]
             y_subsample = y[subsample]
 
             boss = IndividualBOSS(
                 *parameters,
-                alphabet_size=self.alphabet_size,
+                alphabet_size=self._alphabet_size,
                 save_words=False,
+                n_jobs=self._threads_to_use,
                 random_state=self.random_state,
             )
             boss.fit(X_subsample, y_subsample)
             boss._clean()
-            boss.subsample = subsample
+            boss._subsample = subsample
 
-            boss.accuracy = self._individual_train_acc(
+            boss._accuracy = self._individual_train_acc(
                 boss,
                 y_subsample,
                 subsample_size,
                 0 if num_classifiers < self.max_ensemble_size else lowest_acc,
             )
-            if boss.accuracy > 0:
-                weight = math.pow(boss.accuracy, 4)
+            if boss._accuracy > 0:
+                weight = math.pow(boss._accuracy, 4)
             else:
                 weight = 0.000000001
 
             if num_classifiers < self.max_ensemble_size:
-                if boss.accuracy < lowest_acc:
-                    lowest_acc = boss.accuracy
+                if boss._accuracy < lowest_acc:
+                    lowest_acc = boss._accuracy
                     lowest_acc_idx = num_classifiers
-                self.weights.append(weight)
-                self.classifiers.append(boss)
-            elif boss.accuracy > lowest_acc:
-                self.weights[lowest_acc_idx] = weight
-                self.classifiers[lowest_acc_idx] = boss
+                self.weights_.append(weight)
+                self.estimators_.append(boss)
+            elif boss._accuracy > lowest_acc:
+                self.weights_[lowest_acc_idx] = weight
+                self.estimators_[lowest_acc_idx] = boss
                 lowest_acc, lowest_acc_idx = self._worst_ensemble_acc()
 
             num_classifiers += 1
             train_time = time.time() - start_time
 
-        self.n_estimators = len(self.classifiers)
-        self.weight_sum = np.sum(self.weights)
+        self.n_estimators_ = len(self.estimators_)
+        self._weight_sum = np.sum(self.weights_)
+
         return self
 
     def _predict(self, X):
@@ -272,13 +290,13 @@ class ContractableBOSS(BaseClassifier):
 
         Parameters
         ----------
-        X : nested pandas DataFrame of shape (n_instances, 1)
-            Nested dataframe with univariate time-series in cells.
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The data to make predictions for.
 
         Returns
         -------
-        preds : array of shape (n_instances, 1)
-            Predicted class.
+        y : array-like, shape = [n_instances]
+            Predicted class labels.
         """
         rng = check_random_state(self.random_state)
         return np.array(
@@ -293,21 +311,22 @@ class ContractableBOSS(BaseClassifier):
 
         Parameters
         ----------
-        X : pd.DataFrame of shape (n_instances, 1)
+        X : 3D np.array of shape = [n_instances, n_dimensions, series_length]
+            The data to make predict probabilities for.
 
         Returns
         -------
-        dists : array of shape (n_instances, n_classes)
-            Predicted probability of each class.
+        y : array-like, shape = [n_instances, n_classes_]
+            Predicted probabilities using the ordering in classes_.
         """
-        sums = np.zeros((X.shape[0], self.n_classes))
+        sums = np.zeros((X.shape[0], self.n_classes_))
 
-        for n, clf in enumerate(self.classifiers):
+        for n, clf in enumerate(self.estimators_):
             preds = clf.predict(X)
             for i in range(0, X.shape[0]):
-                sums[i, self.class_dictionary[preds[i]]] += self.weights[n]
+                sums[i, self._class_dictionary[preds[i]]] += self.weights_[n]
 
-        dists = sums / (np.ones(self.n_classes) * self.weight_sum)
+        dists = sums / (np.ones(self.n_classes_) * self._weight_sum)
 
         return dists
 
@@ -315,9 +334,9 @@ class ContractableBOSS(BaseClassifier):
         min_acc = 1.0
         min_acc_idx = -1
 
-        for c, classifier in enumerate(self.classifiers):
-            if classifier.accuracy < min_acc:
-                min_acc = classifier.accuracy
+        for c, classifier in enumerate(self.estimators_):
+            if classifier._accuracy < min_acc:
+                min_acc = classifier._accuracy
                 min_acc_idx = c
 
         return min_acc, min_acc_idx
@@ -325,41 +344,51 @@ class ContractableBOSS(BaseClassifier):
     def _unique_parameters(self, max_window, win_inc):
         possible_parameters = [
             [win_size, word_len, normalise]
-            for n, normalise in enumerate(self.norm_options)
+            for n, normalise in enumerate(self._norm_options)
             for win_size in range(self.min_window, max_window + 1, win_inc)
-            for g, word_len in enumerate(self.word_lengths)
+            for g, word_len in enumerate(self._word_lengths)
         ]
 
         return possible_parameters
 
-    def _get_train_probs(self, X):
-        num_inst = X.shape[0]
-        results = np.zeros((num_inst, self.n_classes))
-        for i in range(num_inst):
-            divisor = 0
-            sums = np.zeros(self.n_classes)
+    def _get_train_probs(self, X, y):
+        self.check_is_fitted()
+        X, y = check_X_y(X, y, coerce_to_numpy=True, enforce_univariate=True)
 
-            clf_idx = []
-            for n, clf in enumerate(self.classifiers):
-                idx = np.where(clf.subsample == i)
-                if len(idx[0]) > 0:
-                    clf_idx.append([n, idx[0][0]])
+        n_instances, _, series_length = X.shape
 
-            preds = Parallel(n_jobs=self.n_jobs)(
-                delayed(self.classifiers[cls[0]]._train_predict)(
-                    cls[1],
+        if n_instances != self.n_instances_ or series_length != self.series_length_:
+            raise ValueError(
+                "n_instances, series_length mismatch. X should be "
+                "the same as the training data used in fit for generating train "
+                "probabilities."
+            )
+
+        results = np.zeros((n_instances, self.n_classes_))
+        divisors = np.zeros(n_instances)
+
+        for i, clf in enumerate(self.estimators_):
+            subsample = clf._subsample
+            preds = (
+                clf._train_predictions
+                if self.save_train_predictions
+                else Parallel(n_jobs=self._threads_to_use)(
+                    delayed(clf._train_predict)(
+                        i,
+                    )
+                    for i in range(len(subsample))
                 )
-                for cls in clf_idx
             )
 
             for n, pred in enumerate(preds):
-                sums[self.class_dictionary.get(pred, -1)] += self.weights[clf_idx[n][0]]
-                divisor += self.weights[clf_idx[n][0]]
+                results[subsample[n]][self._class_dictionary[pred]] += self.weights_[i]
+                divisors[subsample[n]] += self.weights_[i]
 
+        for i in range(n_instances):
             results[i] = (
-                np.ones(self.n_classes) * (1 / self.n_classes)
-                if divisor == 0
-                else sums / (np.ones(self.n_classes) * divisor)
+                np.ones(self.n_classes_) * (1 / self.n_classes_)
+                if divisors[i] == 0
+                else results[i] / (np.ones(self.n_classes_) * divisors[i])
             )
 
         return results
@@ -368,8 +397,8 @@ class ContractableBOSS(BaseClassifier):
         correct = 0
         required_correct = int(lowest_acc * train_size)
 
-        if self.n_jobs > 1:
-            c = Parallel(n_jobs=self.n_jobs)(
+        if self._threads_to_use > 1:
+            c = Parallel(n_jobs=self._threads_to_use)(
                 delayed(boss._train_predict)(
                     i,
                 )
@@ -381,6 +410,9 @@ class ContractableBOSS(BaseClassifier):
                     return -1
                 elif c[i] == y[i]:
                     correct += 1
+
+                if self.save_train_predictions:
+                    boss._train_predictions.append(c[i])
         else:
             for i in range(train_size):
                 if correct + train_size - i < required_correct:
@@ -391,4 +423,7 @@ class ContractableBOSS(BaseClassifier):
                 if c == y[i]:
                     correct += 1
 
+                if self.save_train_predictions:
+                    boss._train_predictions.append(c)
+
         return correct / train_size
