@@ -1,9 +1,10 @@
 #!/usr/bin/env python3 -u
 # -*- coding: utf-8 -*-
 # copyright: sktime developers, BSD-3-Clause License (see LICENSE file)
+"""Implements transformations to detrend a time series."""
 
 __all__ = ["Detrender"]
-__author__ = ["Markus Löning", "Svea Meyer"]
+__author__ = ["mloning", "SveaMeyer13"]
 
 from sklearn.base import clone
 import pandas as pd
@@ -15,15 +16,15 @@ from sktime.forecasting.trend import PolynomialTrendForecaster
 
 
 class Detrender(_SeriesToSeriesTransformer):
-    """
-    Remove a trend from a series.
+    """Remove a :term:`trend <Trend>` from a series.
+
     This transformer uses any forecaster and returns the in-sample residuals
     of the forecaster's predicted values.
 
     The Detrender works by first fitting the forecaster to the input data.
     To transform data, it uses the fitted forecaster to generate
     forecasts for the time points of the passed data and returns the residuals
-     of the forecasts.
+    of the forecasts.
     Depending on the passed data, this will require it to generate in-sample
     or out-of-sample forecasts.
 
@@ -38,19 +39,22 @@ class Detrender(_SeriesToSeriesTransformer):
 
     Parameters
     ----------
-    forecaster : estimator object, optional
-        default=None. If None, PolynomialTrendForecaster(degree=1) is used.
-
+    forecaster : estimator object, default=None
+        If forecaster is None, PolynomialTrendForecaster(degree=1) is used.
         The forecasting model to remove the trend with
-        (e.g. PolynomialTrendForecaster)
+        (e.g. PolynomialTrendForecaster).
 
     Attributes
     ----------
     forecaster_ : estimator object
-        Model that defines the trend in the series
+        Model that defines the trend in the series.
 
-    Example
-    ----------
+    See Also
+    --------
+    Deseasonalizer
+
+    Examples
+    --------
     >>> from sktime.transformations.series.detrend import Detrender
     >>> from sktime.forecasting.trend import PolynomialTrendForecaster
     >>> from sktime.datasets import load_airline
@@ -68,15 +72,14 @@ class Detrender(_SeriesToSeriesTransformer):
         super(Detrender, self).__init__()
 
     def fit(self, Z, X=None):
-        """
-        Compute the trend in the series
+        """Compute the trend in the series.
 
         Parameters
         ----------
         Y : pd.Series
             Endogenous time series to fit a trend to.
         X : pd.DataFrame, optional (default=None)
-            Exogenous variables
+            Exogenous variables.
 
         Returns
         -------
@@ -101,20 +104,19 @@ class Detrender(_SeriesToSeriesTransformer):
         return self
 
     def transform(self, Z, X=None):
-        """
-        Remove trend from the data.
+        """Remove trend from the data.
 
         Parameters
         ----------
         y : pd.Series
-            Time series to be detrended
+            Time series to be detrended.
         X : pd.DataFrame, optional (default=False)
-            Exogenous variables
+            Exogenous variables.
 
         Returns
         -------
         y_hat : pd.Series
-            De-trended series
+            De-trended series.
         """
         self.check_is_fitted()
         z = check_series(Z)
@@ -142,20 +144,19 @@ class Detrender(_SeriesToSeriesTransformer):
             return z - z_pred
 
     def inverse_transform(self, Z, X=None):
-        """
-        Add trend back to a time series
+        """Add trend back to a time series.
 
         Parameters
         ----------
         y : pd.Series, list
-            Detrended time series to revert
+            Detrended time series to revert.
         X : pd.DataFrame, optional (default=False)
-            Exogenous variables
+            Exogenous variables.
 
         Returns
         -------
         y_hat : pd.Series
-            Series with the trend
+            Series with the trend.
         """
         self.check_is_fitted()
         z = check_series(Z)
@@ -183,15 +184,14 @@ class Detrender(_SeriesToSeriesTransformer):
             return z + z_pred
 
     def update(self, Z, X=None, update_params=True):
-        """
-        Update the parameters of the detrending estimator with new data
+        """Update the parameters of the detrending estimator with new data.
 
         Parameters
         ----------
         y_new : pd.Series
-            New time series
+            New time series.
         update_params : bool, optional (default=True)
-            Update the parameters of the detrender model with
+            Update the parameters of the detrender model.
 
         Returns
         -------
